/*
This file is part of the Remote ImageJ.
 
(c) 2011 INSERM
This software is developed at Montpellier RIO Imaging (IFR 122), Montpellier, France (www.mri.cnrs.fr)
Developer: Volker Bäcker (volker.baecker@mri.cnrs.fr) 

The Remote ImageJ allows to run ImageJ macros on a distant machine.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms. 
*/
package fr.cnrs.mri.remoteij.client.rfs;
import fr.cnrs.mri.sijame.connection.SIJAMEClient;
import fr.cnrs.mri.sijame.connection.SIJAMEServer;
import fr.cnrs.mri.sijame.messages.RequestMessage;
import fr.cnrs.mri.util.logging.LoggingUtil;

public class RemoteFilesystemClient {

	private SIJAMEClient client;

	public RemoteFilesystemClient(String host, String port) {
		client = SIJAMEClient.currentForHostAndPort(host, Integer.parseInt(port));
		client.setKeepTheLine(true);
	}
	
	public Object sendMessage(String string, Object param1, Object param2) {
		int length = 3;
		if (param2==null) length = 2;
		if (param1==null) length = 1;
		Object[] data = new Object[length];
		data[0] = string;
		if (length>1) data[1] = param1;
		if (length>2) data[2] = param2;
		RequestMessage message = this.getMessageFor(data);
		Object result = this.getClient().sendAndGetAnswer(message);
		if (result!=null && result.equals(SIJAMEServer.getUnhandled())) {
			LoggingUtil.getLoggerFor(this).warning(string + " unhandled by server");
			result = null;
		}
		return result;
	}

	public void close() {
		if (client==null) return;
		client.hangUp();
	}
	
	private RequestMessage getMessageFor(Object[] data) {
		RequestMessage message = new RequestMessage(data);
		message.setReceiver("remote-filesystem-server");
		message.setSenderName(System.getProperty( "user.name" ));
		return message;
	}

	private SIJAMEClient getClient() {
		return client;
	}

	public String ping() {
		String result = (String) this.sendMessage("ping", null, null);
		return result;
	}
}
