/*
This file is part of the Remote ImageJ.
 
(c) 2011 INSERM
This software is developed at Montpellier RIO Imaging (IFR 122), Montpellier, France (www.mri.cnrs.fr)
Developer: Volker Baecker (volker.baecker@mri.cnrs.fr) 

The Remote ImageJ allows to run ImageJ macros on a distant machine.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms. 
*/
package fr.cnrs.mri.remoteij.client.rfs;

import java.io.File;
import java.io.IOException;

import javax.swing.Icon;
import javax.swing.filechooser.FileSystemView;

public class RemoteFilesystemView extends FileSystemView {

	private String host;
	private String port;
	private RemoteFilesystemClient client;

	public RemoteFilesystemView(String host, String port) {
		super();
		this.host = host;
		this.port = port;
	}
	
	@Override
	public File createFileObject(File dir, String filename) {
		File result = (File)this.getClient().sendMessage("createFileObject", dir, filename);
		return result;
	}

	@Override
	public File createFileObject(String path) {
		File result = (File)this.getClient().sendMessage("createFileObject", path, null);
		return result;
	}

	@Override
	public File getChild(File parent, String fileName) {
		File result = (File)this.getClient().sendMessage("getChild", parent, fileName);
		return result;
	}

	@Override
	public File getDefaultDirectory() {
		File result = (File)this.getClient().sendMessage("getDefaultDirectory", null, null);
		return result;
	}

	@Override
	public File[] getFiles(File dir, boolean useFileHiding) {
		File[] result = (File[])this.getClient().sendMessage("getFiles", dir, useFileHiding);
		return result;
	}

	@Override
	public File getHomeDirectory() {
		File result = (File)this.getClient().sendMessage("getHomeDirectory", null, null);
		return result;
	}

	@Override
	public File getParentDirectory(File dir) {
		File result = (File)this.getClient().sendMessage("getParentDirectory", dir, null);
		return result;
	}

	@Override
	public File[] getRoots() {
		File[] result = (File[])this.getClient().sendMessage("getRoots", null, null);
		return result;
	}

	@Override
	public String getSystemDisplayName(File f) {
		return f.getName();
	}

	@Override
	public Icon getSystemIcon(File f) {
		// get remote icons or not?
		return super.getSystemIcon(f);
	}

	@Override
	public String getSystemTypeDescription(File f) {
		String result = (String)this.getClient().sendMessage("getSystemTypeDescription", f, null);
		return result;
	}

	@Override
	public boolean isComputerNode(File dir) {
		// get remote info or not?
		boolean result = super.isComputerNode(dir); 
		return  result;
	}

	@Override
	public boolean isDrive(File dir) {
		// get remote info or not?
		boolean result = super.isDrive(dir);
		return result;
	}

	@Override
	public boolean isFileSystem(File f) {
		boolean result = (Boolean)this.getClient().sendMessage("isFileSystem", f, null);
		return result;
	}

	@Override
	public boolean isFileSystemRoot(File dir) {
		boolean result = (Boolean)this.getClient().sendMessage("isFileSystemRoot", dir, null);
		return result;
	}

	@Override
	public boolean isFloppyDrive(File dir) {
		// get remote info or not?
		boolean result = super.isFloppyDrive(dir);
		return result;
	}

	@Override
	public boolean isHiddenFile(File f) {
		boolean result = (Boolean)this.getClient().sendMessage("isHiddenFile", f, null);
		return result;
	}

	@Override
	public boolean isParent(File folder, File file) {
		boolean result = (Boolean)this.getClient().sendMessage("isParent", folder, file);
		return result;
	}

	@Override
	public boolean isRoot(File f) {
		boolean result = (Boolean)this.getClient().sendMessage("isRoot", f, null);
		return result;
	}

	@Override
	public Boolean isTraversable(File f) {
		Boolean result = (Boolean)this.getClient().sendMessage("isTraversable", f, null);
		return result;
	}

	@Override
	public File createNewFolder(File containingDir) throws IOException {
		File result = (File)this.getClient().sendMessage("createNewFolder", containingDir, null);
		return result;
	}

	private RemoteFilesystemClient getClient() {
		if (this.client==null) {
			this.client = new RemoteFilesystemClient(host, port);
		}
		return client;
	}

	public void close() {
		this.getClient().close();
	}
	
	public String getHost() {
		return host;
	}
	
	public String getPort() {
		return port;
	}
}
