/*
This file is part of the Remote ImageJ.
 
(c) 2011 INSERM
This software is developed at Montpellier RIO Imaging (IFR 122), Montpellier, France (www.mri.cnrs.fr)
Developer: Volker Baecker (volker.baecker@mri.cnrs.fr) 

The Remote ImageJ allows to run ImageJ macros on a distant machine.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms. 
*/
package fr.cnrs.mri.remoteij.server;

import java.awt.Dimension;
import java.awt.Rectangle;
import java.util.Date;
import java.util.Observable;
import java.util.Observer;
import javax.swing.JButton;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import fr.cnrs.mri.logging.LogViewer;

public class ServerPane extends JPanel implements Observer {

	private static final long serialVersionUID = 1L;
	private JLabel portLabel = null;
	private JTextField portTextField = null;
	private JLabel startedLabel = null;
	private JTextField startedTextField = null;
	private JLabel stoppedLabel = null;
	private JTextField stoppedTextField = null;
	private JLabel statusLabel = null;
	private JTextField statusTextField = null;
	private JButton startStopButton = null;
	protected ServerConsole model;
	private JButton logButton = null;
	
	/**
	 * This is the default constructor
	 */
	public ServerPane() {
		super();
		initialize();
	}

	public ServerPane(ServerConsole model) {
		super();
		this.model = model;
		model.addObserver(this);
		initialize();
	}
	
	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {
		this.setSize(292, 227);
		this.setUp();
	}
	
	@Override
	public void update(Observable sender, Object aspect) {
		if (aspect.equals(ServerConsole.Aspect.STATUS)) this.handleStatusChanged();
		if (aspect.equals(ServerConsole.Aspect.START_TIME)) this.handleStartedChanged();
		if (aspect.equals(ServerConsole.Aspect.STOP_TIME)) this.handleStoppedChanged();
	}
	
	private void handleStoppedChanged() {
		this.getStoppedTextField().setText(this.stoppedAsString());
	}

	private void handleStartedChanged() {
		this.getStartedTextField().setText(this.startedAsString());
		
	}

	private void handleStatusChanged() {
		getStatusTextField().setText(model.getStatus().name().toLowerCase());
		String buttonText = "start";
		if (model.getStatus().equals(ServerConsole.Status.RUNNING)) {
			buttonText = "stop";
			getPortTextField().setEditable(false);
		} else {
			getPortTextField().setEditable(true);
		}
		getStartStopButton().setText(buttonText);
	}

	

	/**
	 * This method initializes jContentPane
	 * 
	 * @return javax.swing.JPanel
	 */
	private void setUp() {
			statusLabel = new JLabel();
			statusLabel.setBounds(new Rectangle(22, 41, 69, 15));
			statusLabel.setText("status:");
			stoppedLabel = new JLabel();
			stoppedLabel.setBounds(new Rectangle(22, 93, 69, 15));
			stoppedLabel.setText("stopped:");
			startedLabel = new JLabel();
			startedLabel.setBounds(new Rectangle(22, 67, 69, 15));
			startedLabel.setText("started:");
			portLabel = new JLabel();
			portLabel.setBounds(new Rectangle(22, 16, 43, 15));
			portLabel.setText("port:");
			
			this.setLayout(null);
			this.setPreferredSize(new Dimension(1, 200));
			this.add(portLabel, null);
			this.add(getPortTextField(), null);
			this.add(startedLabel, null);
			this.add(getStartedTextField(), null);
			this.add(stoppedLabel, null);
			this.add(getStoppedTextField(), null);
			this.add(statusLabel, null);
			this.add(getStatusTextField(), null);
			this.add(getStartStopButton(), null);
			this.add(getLogButton(), null);
	}

	/**
	 * This method initializes portTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getPortTextField() {
		if (portTextField == null) {
			portTextField = new JTextField();
			portTextField.setBounds(new Rectangle(102, 14, 72, 19));
			portTextField.setText(Integer.toString(model.getPort()));
			portTextField.addFocusListener(new java.awt.event.FocusAdapter() {
				public void focusLost(java.awt.event.FocusEvent e) {
					handlePortChanged();
				}
			});
			portTextField.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					handlePortChanged();
				}
			});
		}
		return portTextField;
	}

	/**
	 * This method initializes startedTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getStartedTextField() {
		if (startedTextField == null) {
			startedTextField = new JTextField();
			startedTextField.setBounds(new Rectangle(102, 65, 170, 19));
			startedTextField.setEditable(false);
			String startedString = startedAsString();
			startedTextField.setText(startedString);
		}
		return startedTextField;
	}

	private String startedAsString() {
		return dateToString( model.getStarted());
	}
	
	private String stoppedAsString() {
		return dateToString( model.getStopped());
	}

	private String dateToString(Date started) {
		String startedString = "";
		if (started!=null) startedString = started.toString();
		return startedString;
	}

	/**
	 * This method initializes stoppedTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getStoppedTextField() {
		if (stoppedTextField == null) {
			stoppedTextField = new JTextField();
			stoppedTextField.setBounds(new Rectangle(102, 91, 170, 19));
			stoppedTextField.setEditable(false);
			String stoppedString = stoppedAsString();
			stoppedTextField.setText(stoppedString);
		}
		return stoppedTextField;
	}
	
	/**
	 * This method initializes statusTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getStatusTextField() {
		if (statusTextField == null) {
			statusTextField = new JTextField();
			statusTextField.setBounds(new Rectangle(102, 39, 170, 19));
			statusTextField.setEditable(false);
			statusTextField.setText(model.getStatus().name().toLowerCase());
		}
		return statusTextField;
	}

	/**
	 * This method initializes startStopButton	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getStartStopButton() {
		if (startStopButton == null) {
			startStopButton = new JButton();
			startStopButton.setBounds(new Rectangle(22, 169, 69, 19));
			startStopButton.setText("start");
			startStopButton.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					model.startOrStop();
				}
			});
		}
		return startStopButton;
	}

	private void handlePortChanged() {
		int port = 0;
		try {
			port = Integer.parseInt(this.getPortTextField().getText());
		} catch (NumberFormatException exc) {
			return;
		}
		model.setPort(port);
	}

	/**
	 * This method initializes logButton	
	 * 	
	 * @return javax.swing.JButton	
	 */
	private JButton getLogButton() {
		if (logButton == null) {
			logButton = new JButton();
			logButton.setBounds(new Rectangle(118, 169, 69, 19));
			logButton.setText("log");
			logButton.addActionListener(new java.awt.event.ActionListener() {
				public void actionPerformed(java.awt.event.ActionEvent e) {
					new LogViewer("fr.cnrs.mri", 100).show();
				}
			});
		}
		return logButton;
	}
}
