/*
This file is part of the Remote ImageJ.
 
(c) 2011 INSERM
This software is developed at Montpellier RIO Imaging (IFR 122), Montpellier, France (www.mri.cnrs.fr)
Developer: Volker Baecker (volker.baecker@mri.cnrs.fr) 

The Remote ImageJ allows to run ImageJ macros on a distant machine.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms. 
*/
package fr.cnrs.mri.remoteij.server.rfs;

import fr.cnrs.mri.remoteij.server.ServerConfig;

public class RFSServerConfig extends ServerConfig {
	private static final long serialVersionUID = 8111619750963252859L;
	private static RFSServerConfig current;

	public static RFSServerConfig getCurrent() {
		if (current==null) current = new RFSServerConfig();
		return current;
	}
	
	public static void reset() {
		current = null;
	}
	
	@Override
	protected String getComment() {
		return "This is the configuration file of the remote-filesystem-server software.";
	}

	@Override
	public String getFilename() {
		return "rfs-server_config.txt";
	}
	
	public String getFileserverRoot() {
		String fileserverRoot = this.getProperty("fileserver_root");
		if (fileserverRoot==null) {
			fileserverRoot = "/media/donnees/mri/projects/ImageJMS/fileserver/";
			this.setFileserverRoot(fileserverRoot);
		}
		return fileserverRoot;
	}
	
	public void setFileserverRoot(String root) {
		this.load();
		this.setProperty("fileserver_root", root);
		this.save();
	}
	
	public boolean getUseUserFolders() {
		String useUserFoldersString = this.getProperty("use_user_folders");
		if (useUserFoldersString==null) {
			useUserFoldersString = "true";
			this.setUseUserFolders(Boolean.getBoolean(useUserFoldersString));
		}
		boolean result = useUserFoldersString.trim().equalsIgnoreCase("true"); 
		return result;
	}
	
	public void setUseUserFolders(boolean b) {
		this.load();
		this.setProperty("use_user_folders", Boolean.toString(b));
		this.save();
	}

}
