/*
This file is part of the Remote ImageJ.
 
(c) 2011 INSERM
This software is developed at Montpellier RIO Imaging (IFR 122), Montpellier, France (www.mri.cnrs.fr)
Developer: Volker Baecker (volker.baecker@mri.cnrs.fr) 

The Remote ImageJ allows to run ImageJ macros on a distant machine.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms. 
*/
package fr.cnrs.mri.remoteij.server.rmr;

import java.util.Observable;
import fr.cnrs.mri.remoteij.server.ServerConfig;
import fr.cnrs.mri.remoteij.server.ServerConsole;
import fr.cnrs.mri.remoteij.server.ServerView;
import fr.cnrs.mri.server.Server;

public class RMRServerConsole  extends ServerConsole {
	public enum Aspect {NUMBER_OF_MACROS};
	
	private int numberOfMacros = 0;
	private RMRServerConsoleView view;
	
	public RMRServerConsole() {
		super();
	}
	
	public static void main(String[] args) {
		new RMRServerConsole().show();
	}
	
	protected void changed(Aspect anAspect) {
		this.setChanged();
		this.notifyObservers(anAspect);
		this.clearChanged();
	}
	
	protected ServerView getView() {
		if (this.view==null) this.view = new RMRServerConsoleView(this);
		return view;
	}

	@Override
	public void update(Observable sender, Object aspect) {
		super.update(sender, aspect);
		if (aspect.equals(RemoteMacroRunnerServer.Aspect.EXECUTED_MACRO)) this.incrementNumberOfMacros();
	}

	private void incrementNumberOfMacros() {
		this.numberOfMacros++;
		this.changed(Aspect.NUMBER_OF_MACROS);
	}
	
	public int getNumberOfMacros() {
		return numberOfMacros;
	}

	public int getNumberOfMacrosInQueue() {
		if (server==null) return 0;
		return ((RemoteMacroRunnerServer)server).getNumberOfMacrosInQueue();
	}

	@Override
	protected Server getNewServer() {
		return new RemoteMacroRunnerServer(this.getPort());
	}

	@Override
	public int logFileSizeLimit() {
		return 20*1000*1000;
	}

	@Override
	public String name() {
		return "RMR_Server_Console";
	}

	@Override
	public int numberOfLogFiles() {
		return 10;
	}

	@Override
	public String subsystemToLog() {
		return "fr.cnrs.mri";
	}

	@Override
	protected ServerConfig getConfig() {
		return RMRServerConfig.getCurrent();
	}
}
