/*
This file is part of the Remote ImageJ.
 
(c) 2011 INSERM
This software is developed at Montpellier RIO Imaging (IFR 122), Montpellier, France (www.mri.cnrs.fr)
Developer: Volker Baecker (volker.baecker@mri.cnrs.fr) 

The Remote ImageJ allows to run ImageJ macros on a distant machine.

This software is governed by the CeCILL-B license under French law and
abiding by the rules of distribution of free software.  You can  use, 
modify and/ or redistribute the software under the terms of the CeCILL-B
license as circulated by CEA, CNRS and INRIA at the following URL
"http://www.cecill.info". 

As a counterpart to the access to the source code and  rights to copy,
modify and redistribute granted by the license, users are provided only
with a limited warranty  and the software's author,  the holder of the
economic rights,  and the successive licensors  have only  limited
liability. 

In this respect, the user's attention is drawn to the risks associated
with loading,  using,  modifying and/or developing or reproducing the
software by the user in light of its specific status of free software,
that may mean  that it is complicated to manipulate,  and  that  also
therefore means  that it is reserved for developers  and  experienced
professionals having in-depth computer knowledge. Users are therefore
encouraged to load and test the software's suitability as regards their
requirements in conditions enabling the security of their systems and/or 
data to be ensured and,  more generally, to use and operate it in the 
same conditions as regards security. 

The fact that you are presently reading this means that you have had
knowledge of the CeCILL-B license and that you accept its terms. 
*/
package fr.cnrs.mri.remoteij.server.rmr;

import java.awt.BorderLayout;
import javax.swing.JPanel;
import java.util.Observable;
import java.util.Observer;
import javax.swing.JLabel;
import java.awt.Rectangle;
import javax.swing.JTextField;
import fr.cnrs.mri.remoteij.server.ServerPane;
import fr.cnrs.mri.remoteij.server.ServerView;
import fr.cnrs.mri.remoteij.server.rmr.RMRServerConsole.Aspect;

public class RMRServerConsoleView extends ServerView implements Observer {

	private static final long serialVersionUID = 1L;
	private JPanel jContentPane = null;
	private JPanel jPanel = null;
	private JLabel macrosExecutedLabel = null;
	private JTextField macrosExecutedTextField = null;
	private JLabel jLabel = null;
	private JTextField macrosWaitingTextField = null;
	protected RMRServerConsole model;
	
	@Override
	public void update(Observable sender, Object aspect) {
		if (aspect.equals(Aspect.NUMBER_OF_MACROS)) this.handleNumberOfMacrosChanged();
	}

	private void handleNumberOfMacrosChanged() {
		this.getMacrosExecutedTextField().setText(Integer.toString(model.getNumberOfMacros()));
		this.getMacrosWaitingTextField().setText(Integer.toString(model.getNumberOfMacrosInQueue()-1));
	}

	/**
	 * This is the default constructor
	 */
	public RMRServerConsoleView() {
		super();
		model = new RMRServerConsole();
		model.addObserver(this);
		initialize();
	}

	public RMRServerConsoleView(RMRServerConsole model) {
		super();
		this.model = model;
		model.addObserver(this);
		initialize();
	}
	
	/**
	 * This method initializes this
	 * 
	 * @return void
	 */
	private void initialize() {
		this.setSize(292, 227);
		this.setContentPane(getJContentPane());
		this.setTitle("Remote Macro Runner Server Console");
	}

	/**
	 * This method initializes jContentPane
	 * 
	 * @return javax.swing.JPanel
	 */
	private JPanel getJContentPane() {
		if (jContentPane == null) {
			jContentPane = new JPanel();
			jContentPane.setLayout(new BorderLayout());
			jContentPane.add(getJPanel(), BorderLayout.NORTH);
		}
		return jContentPane;
	}

	/**
	 * This method initializes jPanel	
	 * 	
	 * @return javax.swing.JPanel	
	 */
	private JPanel getJPanel() {
		if (jPanel == null) {
			jPanel = new ServerPane(model);
			jLabel = new JLabel();
			jLabel.setBounds(new Rectangle(22, 142, 131, 15));
			jLabel.setText("macros waiting:");
			macrosExecutedLabel = new JLabel();
			macrosExecutedLabel.setBounds(new Rectangle(22, 117, 131, 15));
			macrosExecutedLabel.setText("macros executed:");
			jPanel.add(macrosExecutedLabel, null);
			jPanel.add(getMacrosExecutedTextField(), null);
			jPanel.add(jLabel, null);
			jPanel.add(getMacrosWaitingTextField(), null);
		}
		return jPanel;
	}



	/**
	 * This method initializes macrosExecutedTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getMacrosExecutedTextField() {
		if (macrosExecutedTextField == null) {
			macrosExecutedTextField = new JTextField();
			macrosExecutedTextField.setBounds(new Rectangle(169, 115, 72, 19));
			macrosExecutedTextField.setEditable(false);
			macrosExecutedTextField.setText(Integer.toString(model.getNumberOfMacros()));
		}
		return macrosExecutedTextField;
	}

	/**
	 * This method initializes macrosWaitingTextField	
	 * 	
	 * @return javax.swing.JTextField	
	 */
	private JTextField getMacrosWaitingTextField() {
		if (macrosWaitingTextField == null) {
			macrosWaitingTextField = new JTextField();
			macrosWaitingTextField.setBounds(new Rectangle(169, 140, 72, 19));
			macrosWaitingTextField.setEditable(false);
			macrosWaitingTextField.setText(Integer.toString(model.getNumberOfMacrosInQueue()));
		}
		return macrosWaitingTextField;
	}



}  //  @jve:decl-index=0:visual-constraint="10,10"
