package tests.fr.cnrs.mri.remoteij.client.rmr;

import java.io.File;
import junit.framework.Assert;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import fr.cnrs.mri.remoteij.client.rmr.RemoteMacroRunnerClient;
import fr.cnrs.mri.remoteij.server.rmr.RemoteMacroRunnerServer;
import fr.cnrs.mri.sijame.connection.SIJAMEClient;
import fr.cnrs.mri.testData.TestConfig;

public class RemoteMacroRunnerClientTest {
	private RemoteMacroRunnerClient client;
	private RemoteMacroRunnerServer server;
	private int serverPort = 4001;
	
	public static String findEdgesTestMacro() {
		return "run(\"Bridge (174K)\");" + "\n" + 
			   "run(\"Find Edges\");" +"\n" + 
			   "saveAs(\"Jpeg\", \"" + TestConfig.testFolder + "bridge.jpg\");" + "\n" +
			   "return \"done\";";
	}
	
	public static String simpleTestMacro() {
		return "return toString(2 + 2);";
	}
	
	@Before
	public void setUp() {
		server = new RemoteMacroRunnerServer(serverPort);
		server.start();
		client = new RemoteMacroRunnerClient();	
		client.setServer(SIJAMEClient.getIpAddress());
		client.setServerPort(serverPort);
		client.setPort(serverPort-1);
	}

	@After
	public void tearDown() {
		server.stop();
	}
	
	@Test
	public void testRunSimpleMacro() throws InterruptedException {
		client.runMacro(simpleTestMacro());
		while(client.getLastResult()==null) Thread.sleep(10);
		Assert.assertEquals("4", client.getLastResult());
	}
	
	@Test
	public void testFindEdgesTestMacro() throws InterruptedException {
		System.setProperty("user.dir", "../../run"); 
		File file = new File(TestConfig.testFolder + "/bridge.jpg" );
		file.delete();
		Assert.assertFalse(file.exists());
		client.runMacro(findEdgesTestMacro());
		while(client.getLastResult()==null) Thread.sleep(10);
		Assert.assertEquals("done",client.getLastResult());
		Assert.assertTrue(file.exists());
		file.delete();
	}
}
